==> ranshark-1.0.0.3-py3-none-any.whl: drawranflow/views.py <==
# views.py
import logging
from concurrent.futures import ThreadPoolExecutor
import pyshark
from django.http import JsonResponse, FileResponse, HttpResponseServerError
import os
from django.utils.encoding import smart_str
from django.conf import settings
from django.shortcuts import render
import json
from .models import UploadedFile, Identifiers, Message, Stats, IdentifiersStats
from celery import shared_task
from drawranflow.servicelogic.handlers.processPackets import packetHandler as ph
from django.views.decorators.csrf import csrf_exempt
from .servicelogic.handlers.stats_handler import computeStats as sh
from .servicelogic.handlers.files_handler import FileHandlers as fh

BASE_DIR = getattr(settings, 'BASE_DIR', None)
MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', None)


# home Landing page
def home(request):
    return render(request, 'home.html')


# upload_file Handling upload file
def upload_file(request):
    messages = {}
    if request.method == 'POST':
        file = request.FILES.get('file_upload')
        messages = fh.upload_pcap_file(file=file)
    return JsonResponse(messages)


# delete_file Handling delete file request
def delete_file(request, item_id):
    try:
        item = UploadedFile.objects.get(id=item_id)
        # Delete the associated file from the media path
        if item:
            file_path = item.filename
            file_path = os.path.join(settings.MEDIA_ROOT, file_path)
            logging.debug(f"files to be deleted {file_path}")
            if os.path.exists(file_path):
                fh.delete_files(file_path)
                # Delete the item from the database
            item.delete()

        return JsonResponse({'message_type': 'success', 'message_text': f'{item.filename} deleted successfully'},
                            status=200)
    except UploadedFile.DoesNotExist:
        return JsonResponse({'message': 'Item not found'}, status=404)
    except Exception as e:
        return JsonResponse({'message': f'Error: {str(e)}'}, status=500)


# process_file Handling process file request
def process_file(request, item_id):
    try:
        item = UploadedFile.objects.get(id=item_id)
        # Delete the associated file from the media path
        if item:
            file_path = item.filename
            file_path = os.path.join(settings.MEDIA_ROOT, file_path)
            if os.path.exists(file_path):
                f = f'{file_path}'
                tmp = f'{item.filename}'.split('.')[0]
                csv = f'{settings.MEDIA_ROOT}/{tmp}.csv'
                # Use ThreadPoolExecutor to run the function asynchronously
                with ThreadPoolExecutor() as executor:
                    executor.submit(async_process_file, f, csv, item_id)

        return JsonResponse(
            {'message_type': 'success', 'message_text': f'{item.filename} process started successfully'}, status=200)
    except UploadedFile.DoesNotExist:
        return JsonResponse({'message_type': 'error', 'message': 'file not found'}, status=404)
    except Exception as e:
        return JsonResponse({'message_type': 'error', 'message': f'Error: {str(e)}'}, status=500)


# async_process_file
@shared_task
def async_process_file(filename, csv, item_id):
    # Run the file processing asynchronously
    ph(input_pcap=filename, output_csv=csv, item_id=item_id).capture_packets_and_save_to_csv()


# check_file_existence to check if the file is already exists
def check_file_existence(request):
    file_exists = False
    if request.method == "POST":
        file_name = request.POST.get('file_name')
        try:
            if UploadedFile.objects.filter(filename=file_name).exists():
                # File exists in the database
                file_exists = True
        except Exception as e:
            # Handle any exceptions or errors
            logging.error("Error checking file existence:", str(e))
    return JsonResponse({'file_exists': file_exists})


# streaming_table_view streaming the list view
def streaming_table_view(request):
    # Retrieve data from the MainTable model
    id = request.GET.get('id')
    identifiers_table_data = Identifiers.objects.filter(uploadedFiles_id=id).order_by('id').values()

    # Convert the data to a list
    data = list(identifiers_table_data)
    return JsonResponse(data, safe=False)


# display_streaming_table streaming table view as list
def display_streaming_table(request, id):
    context = {
        'id': id,
    }
    return render(request, 'streaming_table.html', context)


# fetch_associated_data fetching all messages related to a Call
def fetch_associated_data(request, main_id):
    try:
        messages = Message.objects.filter(identifiers=main_id).order_by('FrameTime')
        messages_list = []  # List to store all associated data for the main_id

        for message in messages:
            message_data = {
                'message_key': message.id,
                'FrameNumber': message.FrameNumber,
                'FrameTime': str(message.FrameTime),
                'IpSrc': message.IpSrc,
                'IpDst': message.IpDst,
                'Protocol': message.Protocol,
                'F1_Proc': message.F1_Proc,
                'E1_Proc': message.E1_Proc,
                'NG_Proc': message.NG_Proc,
                'C1_RRC': message.C1_RRC,
                'C2_RRC': message.C2_RRC,
                'MM_Message_Type': message.MM_Message_Type,
                'SM_Message_Type': message.SM_Message_Type,
                'Message': message.Message,
                'srcNode': message.srcNode,
                'dstNode': message.dstNode,
                'message_json': message.message_json,
            }
            messages_list.append(message_data)

        return messages_list

    except Message.DoesNotExist:
        # Handle the case where the message with the given id is not found
        return None
    except Exception as e:
        # Handle other exceptions
        raise e


@csrf_exempt
def prepare_download_pcap(request):
    uploadfile = ""

    try:
        # Retrieve main_id from the request's GET parameters
        main_id = request.GET.get('main_id')
        logging.debug(f"main id: {main_id}")

        # Fetch data based on the main_id from the Identifiers table
        identifier_data = fh.fetch_identifier_data(main_id)

        # Construct a filter based on the identifier data
        if identifier_data:
            pcap_filter = fh.construct_pcap_filter(identifier_data)
            logging.debug(f"identifier_data: {identifier_data}")

            if pcap_filter:
                uploadfile = UploadedFile.objects.get(id=identifier_data.uploadedFiles_id)

                filename = uploadfile.filename
                f = filename.split('.')
                # Filter the original pcap file and save the filtered file
                original_pcap_path = os.path.join(settings.MEDIA_ROOT, filename)

                outputfile = os.path.join(settings.MEDIA_ROOT,
                                          f"{f[0]}_{identifier_data.C_RNTI}_{identifier_data.GNB_DU_UE_F1AP_ID}.pcap")
                logging.debug(f'original_pcap_path={original_pcap_path}, outputfile={outputfile}')
                outputfile = fh.filter_pcap(original_pcap_path, pcap_filter, outputfile)

                # Check if the file exists before trying to open it
                if os.path.exists(outputfile) and outputfile:
                    response = FileResponse(open(outputfile, 'rb'), content_type="application/vnd.tcpdump.pcap")
                    response[
                        "Content-Disposition"] = f'attachment; filename="{smart_str(os.path.basename(outputfile))}"'
                    return response
                else:
                    return JsonResponse({'error': 'Filtered file not found'}, status=404)
        else:
            return JsonResponse({'error': 'Identifier data not found'}, status=404)
    except Exception as e:
        logging.error(f"Error: {str(e)}")
        return JsonResponse({'error': str(e)}, status=500)


# fetch_packet_data fetching packet data
def fetch_packet_data(request):
    main_id = request.GET.get('main_id')
    logging.debug(f"main id: {main_id}")

    # Fetch data based on the main_id from the Identifiers table
    identifier_data = fh.fetch_identifier_data(main_id)
    original_pcap_path = None
    # Construct a filter based on the identifier data
    if identifier_data:
        logging.debug(f"identifier_data: {identifier_data}")
        uploadfile = UploadedFile.objects.get(id=identifier_data.uploadedFiles_id)
        filename = uploadfile.filename
        original_pcap_path = os.path.join(settings.MEDIA_ROOT, filename)

    frame_numbers = [message.FrameNumber for message in Message.objects.filter(
                        identifiers_id=identifier_data.id
                        ).order_by('FrameTime')]

    if frame_numbers and original_pcap_path:
        frame_filter = '||'.join([f'frame.number=={fn}' for fn in frame_numbers])
        logging.debug(f"frame_filter - {frame_filter}")

        try:
            # Use PyShark to filter packets based on frame numbers
            if os.path.exists(original_pcap_path):
                with pyshark.FileCapture(original_pcap_path, display_filter=frame_filter) as packets:
                    packets.set_debug()
                    for packet in packets:
                        pduType = sh.packetLayers(packet=packet)
                        test = sh.packet_to_json(pduType)
                        if test:
                            # Find the message associated with the current frame number
                            matching_message = next(
                                (message for message in Message.objects.filter(identifiers_id=identifier_data.id) if
                                 message.FrameNumber == int(packet.frame_info.number)), None)
                            if matching_message:
                                matching_message.message_json = test
                                matching_message.save()
        except Exception as e:
            logging.error(f"Error capturing packets: {e}")

    associated_data = fetch_associated_data(request, main_id)
    logging.debug(f"associated_data- {associated_data}")

    # Render the draw-sequence view with the associated data
    if associated_data:
        associated_data = json.dumps(associated_data)
        context = {'main_id': main_id, 'associated_data': associated_data}
        return render(request, 'draw_sequence.html', context)
    else:
        return render(request, 'draw_sequence.html')


def draw_sequence_view(request, main_id):
    if main_id is not None:
        filter_string = ""
        # Fetch associated data using  fetch_associated_data function
        associated_data = fetch_associated_data(request, main_id)
        identifier_data = fh.fetch_identifier_data(main_id)
        if identifier_data:
            filter_string = fh.construct_pcap_filter(identifier_data)
        # Render the draw-sequence view with the associated data
        associated_data = json.dumps(associated_data)
        context = {'main_id': main_id, 'associated_data': associated_data, 'filter_string': filter_string}

        return render(request, 'draw_sequence.html', context)
    else:
        return render(request, 'draw_sequence.html')


def get_updated_table_data(request):
    # Query the UploadedFile model and prepare data to send as JSON
    data = UploadedFile.objects.values('id', 'filename', 'upload_date', 'proces_date', 'processed', 'completed',
                                       'complete_at').order_by('id')
    return JsonResponse(list(data), safe=False)


# def showCucpWiseStats(request,id):
#     unique_cucp_ips = sh.get_cucp_ips(id)
#     context = {'cucp_ips': unique_cucp_ips}
#     return  render(request,'show_stats.html',context)


def show_stats(request, id):
    try:
        upload_file_id = id
        cumulative_stat_list = []
        identifier_stat_list = []
        sh.update_stats_by_id(upload_file_id)
        cumulative_stats = Stats.objects.filter(uploadedFiles_id=upload_file_id)
        for cumulative_stat in cumulative_stats:
            cumulative_stat_list.append({
                'category': cumulative_stat.category,
                'attempts': cumulative_stat.attempts,
                'success': cumulative_stat.success,
                'fails': cumulative_stat.fails,
                'timeouts': cumulative_stat.timeouts,
                'cucp_ip': cumulative_stat.cucp_f1c_ip
            })
        identifiers = IdentifiersStats.objects.filter(uploadedFiles_id=upload_file_id).order_by('identifier_id')
        unique_cucp_ips = sh.get_cucp_ips(id)

        identifier_stat_list = []
        for identifier in identifiers:
            identifier_stat_list.append({
                'identifier_id': identifier.identifier_id,
                'identifier_attempt': identifier.attempts,
                'identifier_success': identifier.success,
                'identifier_timeout': identifier.timeouts,
                "identifier_category": identifier.category,
                'identifier_fails': identifier.fails,
                'cucp_ip': identifier.cucp_f1c_ip

            })
        context = {
            'cumulative_stat_list': cumulative_stat_list,
            'identifier_stats_list': identifier_stat_list,
            'cucp_ips': unique_cucp_ips,
            "id": id,
        }
        print(unique_cucp_ips, cumulative_stat_list)
        return render(request, 'show_stats.html', context)
    except Exception as e:
        # Log the exception for debugging purposes
        logging.error(f"Error in show_stats view: {e}")
        return HttpResponseServerError("An error occurred while processing your request.")

==> ranshark-1.0.0.4-py3-none-any.whl: drawranflow/views.py <==
# views.py
import logging
from concurrent.futures import ThreadPoolExecutor
import pyshark
from django.http import JsonResponse, FileResponse, HttpResponseServerError
import os
from django.utils.encoding import smart_str
from django.conf import settings
from django.shortcuts import render
import json
from .models import UploadedFile, Identifiers, Message, Stats, IdentifiersStats
from celery import shared_task
from drawranflow.servicelogic.handlers.processPackets import packetHandler as ph
from django.views.decorators.csrf import csrf_exempt

from .servicelogic.handlers.stats_handler import computeStats as sh
from .servicelogic.handlers.files_handler import FileHandlers as fh
import transformers

BASE_DIR = getattr(settings, 'BASE_DIR', None)
MEDIA_ROOT = getattr(settings, 'MEDIA_ROOT', None)


# home Landing page
def home(request):
    return render(request, 'home.html')


# upload_file Handling upload file
def upload_file(request):
    messages = {}
    if request.method == 'POST':
        file = request.FILES.get('file_upload')
        messages = fh.upload_pcap_file(file=file)
    return JsonResponse(messages)


# delete_file Handling delete file request
def delete_file(request, item_id):
    try:
        item = UploadedFile.objects.get(id=item_id)
        # Delete the associated file from the media path
        if item:
            file_path = item.filename
            file_path = os.path.join(settings.MEDIA_ROOT, file_path)
            logging.debug(f"files to be deleted {file_path}")
            if os.path.exists(file_path):
                fh.delete_files(file_path)
                # Delete the item from the database
            item.delete()

        return JsonResponse({'message_type': 'success', 'message_text': f'{item.filename} deleted successfully'},
                            status=200)
    except UploadedFile.DoesNotExist:
        return JsonResponse({'message': 'Item not found'}, status=404)
    except Exception as e:
        return JsonResponse({'message': f'Error: {str(e)}'}, status=500)


def process_file_async(item):
    try:
        file_path = os.path.join(MEDIA_ROOT, item.filename)
        f = f'{file_path}'
        tmp = f'{item.filename}'.split('.')[0]
        csv = f'{MEDIA_ROOT}/{tmp}.csv'
        ph(input_pcap=f, output_csv=csv, item_id=item.id).capture_packets_and_save_to_csv()
        return {'message_type': 'success', 'message_text': f'{item.filename} process started successfully'}
    except Exception as e:
        return {'message_type': 'error', 'message': f'Error: {str(e)}'}


def process_file(request, item_id):
    try:
        item = UploadedFile.objects.get(id=item_id)
        if item:
            with ThreadPoolExecutor() as executor:
                # Submit the task to the thread pool
                future = executor.submit(process_file_async, item)

        return JsonResponse(
            {'message_type': 'success', 'message_text': f'{item.filename} process started successfully'}, status=200)
    except UploadedFile.DoesNotExist:
        return JsonResponse({'message_type': 'error', 'message': 'file not found'}, status=404)
    except Exception as e:
        return JsonResponse({'message_type': 'error', 'message': f'Error: {str(e)}'}, status=500)


#
#
# # process_file Handling process file request
# def process_file(request, item_id):
#     try:
#         item = UploadedFile.objects.get(id=item_id)
#         # Delete the associated file from the media path
#         if item:
#             file_path = item.filename
#             file_path = os.path.join(settings.MEDIA_ROOT, file_path)
#             if os.path.exists(file_path):
#                 f = f'{file_path}'
#                 tmp = f'{item.filename}'.split('.')[0]
#                 csv = f'{settings.MEDIA_ROOT}/{tmp}.csv'
#                 # Use ThreadPoolExecutor to run the function asynchronously
#                 with ThreadPoolExecutor() as executor:
#                     executor.submit(ph(input_pcap=f, output_csv=csv, item_id=item_id).capture_packets_and_save_to_csv())
#
#         return JsonResponse(
#             {'message_type': 'success', 'message_text': f'{item.filename} process started successfully'}, status=200)
#     except UploadedFile.DoesNotExist:
#         return JsonResponse({'message_type': 'error', 'message': 'file not found'}, status=404)
#     except Exception as e:
#         return JsonResponse({'message_type': 'error', 'message': f'Error: {str(e)}'}, status=500)
#

# check_file_existence to check if the file is already exists
def check_file_existence(request):
    file_exists = False
    if request.method == "POST":
        file_name = request.POST.get('file_name')
        try:
            if UploadedFile.objects.filter(filename=file_name).exists():
                # File exists in the database
                file_exists = True
        except Exception as e:
            # Handle any exceptions or errors
            logging.error("Error checking file existence:", str(e))
    return JsonResponse({'file_exists': file_exists})


# streaming_table_view streaming the list view
def streaming_table_view_bkup(request):
    # Retrieve data from the MainTable model
    id = request.GET.get('id')
    print(id)
    identifiers_table_data = Identifiers.objects.filter(uploaded_file_id=id).order_by('id').values()

    # Convert the data to a list
    data = list(identifiers_table_data)
    print(data)
    return JsonResponse(data, safe=False)


def streaming_table_view(request):
    # Retrieve data from the MainTable model
    id = request.GET.get('id')
    identifiers_table_data = Identifiers.objects.filter(uploaded_file_id=id).order_by('id').values()

    # Convert the data to a list of dictionaries with the expected format
    data = [
        {
            'id': item['id'],
            'gnb_id': item['gnb_id'],
            'c_rnti': item['c_rnti'],
            'gnb_du_ue_f1ap_id': item['gnb_du_ue_f1ap_id'],
            'gnb_cu_ue_f1ap_id': item['gnb_cu_ue_f1ap_id'],
            'gnb_cu_cp_ue_e1ap_id': item['gnb_cu_cp_ue_e1ap_id'],
            'gnb_cu_up_ue_e1ap_id': item['gnb_cu_up_ue_e1ap_id'],
            'ran_ue_ngap_id': item['ran_ue_ngap_id'],
            'amf_ue_ngap_id': item['amf_ue_ngap_id'],
            'xnap_src_ran_id': item['xnap_src_ran_id'],
            'xnap_trgt_ran_id': item['xnap_trgt_ran_id'],
            'pci': item['pci'],
            'f1ap_cause': item['f1ap_cause'],
            'ngap_cause': item['ngap_cause'],
        }
        for item in identifiers_table_data
    ]
    return JsonResponse(data, safe=False)


# display_streaming_table streaming table view as list
def display_streaming_table(request, id):
    context = {
        'id': id,
    }

    return render(request, 'streaming_table.html', context)


# fetch_associated_data fetching all messages related to a Call
def fetch_associated_data(request, main_id):
    try:
        messages = Message.objects.filter(identifiers=main_id).order_by('frame_time')
        messages_list = []  # List to store all associated data for the main_id

        for message in messages:
            message_data = {
                'message_key': message.id,
                'frame_number': message.frame_number,
                'ip_src': message.ip_src,
                'ip_dst': message.ip_dst,
                'protocol': message.protocol,
                'f1_proc': message.f1_proc,
                'e1_proc': message.e1_proc,
                'ng_proc': message.ng_proc,
                'c1_rrc': message.c1_rrc,
                'c2_rrc': message.c2_rrc,
                'mm_message_type': message.mm_message_type,
                'sm_message_type': message.sm_message_type,
                'message': message.message,
                'src_node': message.src_node,
                'dst_node': message.dst_node,
                'message_json': message.message_json,
                'c_rnti': message.c_rnti,
                'gnb_du_ue_f1ap_id': message.gnb_du_ue_f1ap_id,
                'gnb_cu_ue_f1ap_id': message.gnb_cu_ue_f1ap_id,
                'gnb_cu_cp_ue_e1ap_id': message.gnb_cu_cp_ue_e1ap_id,
                'gnb_cu_up_ue_e1ap_id': message.gnb_cu_up_ue_e1ap_id,
                'ran_ue_ngap_id': message.ran_ue_ngap_id,
                'amf_ue_ngap_id': message.amf_ue_ngap_id,
                'xnap_src_ran_id': message.xnap_src_ran_id,
                'xnap_trgt_ran_id': message.xnap_trgt_ran_id,
            }

            # Use message_data as needed

            messages_list.append(message_data)
        return messages_list

    except Message.DoesNotExist:
        # Handle the case where the message with the given id is not found
        return None
    except Exception as e:
        # Handle other exceptions
        raise e


@csrf_exempt
def prepare_download_pcap(request):
    uploadfile = ""

    try:
        # Retrieve main_id from the request's GET parameters
        main_id = request.GET.get('main_id')
        logging.debug(f"main id: {main_id}")

        # Fetch data based on the main_id from the Identifiers table
        identifier_data = fh.fetch_identifier_data(main_id)

        # Construct a filter based on the identifier data
        if identifier_data:
            pcap_filter = fh.construct_pcap_filter(identifier_data)
            logging.debug(f"identifier_data: {identifier_data}")

            if pcap_filter:
                uploadfile = UploadedFile.objects.get(id=identifier_data.uploaded_file_id)

                filename = uploadfile.filename
                f = filename.split('.')
                # Filter the original pcap file and save the filtered file
                original_pcap_path = os.path.join(settings.MEDIA_ROOT, filename)

                outputfile = os.path.join(settings.MEDIA_ROOT,
                                          f"{f[0]}_{identifier_data.c_rnti}_{identifier_data.gnb_du_ue_f1ap_id}.pcap")
                logging.debug(f'original_pcap_path={original_pcap_path}, outputfile={outputfile}')
                outputfile = fh.filter_pcap(original_pcap_path, pcap_filter, outputfile)

                # Check if the file exists before trying to open it
                if os.path.exists(outputfile) and outputfile:
                    response = FileResponse(open(outputfile, 'rb'), content_type="application/vnd.tcpdump.pcap")
                    response[
                        "Content-Disposition"] = f'attachment; filename="{smart_str(os.path.basename(outputfile))}"'
                    return response
                else:
                    return JsonResponse({'error': 'Filtered file not found'}, status=404)
        else:
            return JsonResponse({'error': 'Identifier data not found'}, status=404)
    except Exception as e:
        logging.error(f"Error: {str(e)}")
        return JsonResponse({'error': str(e)}, status=500)


# fetch_packet_data fetching packet data
def fetch_packet_data(request):
    main_id = request.GET.get('main_id')
    logging.debug(f"main id: {main_id}")

    # Fetch data based on the main_id from the Identifiers table
    identifier_data = fh.fetch_identifier_data(main_id)
    original_pcap_path = None
    # Construct a filter based on the identifier data
    if identifier_data:
        logging.debug(f"identifier_data: {identifier_data}")
        uploadfile = UploadedFile.objects.get(id=identifier_data.uploaded_file_id)
        filename = uploadfile.filename
        original_pcap_path = os.path.join(settings.MEDIA_ROOT, filename)

    frame_numbers = [message.frame_number for message in Message.objects.filter(
        identifiers_id=identifier_data.id
    ).order_by('frame_time')]

    if frame_numbers and original_pcap_path:
        frame_filter = '||'.join([f'frame.number=={fn}' for fn in frame_numbers])
        logging.debug(f"frame_filter - {frame_filter}")

        try:
            # Use PyShark to filter packets based on frame numbers
            if os.path.exists(original_pcap_path):
                with pyshark.FileCapture(original_pcap_path, display_filter=frame_filter) as packets:
                    packets.set_debug()
                    for packet in packets:
                        pduType = sh.packetLayers(packet=packet)
                        test = sh.packet_to_json(pduType)
                        if test:
                            # Find the message associated with the current frame number
                            matching_message = next(
                                (message for message in Message.objects.filter(identifiers_id=identifier_data.id) if
                                 message.frame_number == int(packet.frame_info.number)), None)
                            if matching_message:
                                matching_message.message_json = test
                                matching_message.save()
        except Exception as e:
            logging.error(f"Error capturing packets: {e}")

    associated_data = fetch_associated_data(request, main_id)
    logging.debug(f"associated_data- {associated_data}")

    # Render the draw-sequence view with the associated data
    if associated_data:
        associated_data = json.dumps(associated_data)
        context = {'main_id': main_id, 'associated_data': associated_data}
        return render(request, 'draw_sequence.html', context)
    else:
        return render(request, 'draw_sequence.html')


def draw_sequence_view(request, main_id):
    if main_id is not None:
        filter_string = ""
        # Fetch associated data using  fetch_associated_data function
        associated_data = fetch_associated_data(request, main_id)
        identifier_data = fh.fetch_identifier_data(main_id)
        if identifier_data:
            filter_string = fh.construct_pcap_filter(identifier_data)
        # Render the draw-sequence view with the associated data
        logging.debug(f"associated_data- {associated_data}")

        associated_data = json.dumps(associated_data)
        logging.debug(f"associated_data- {associated_data}")
        context = {'main_id': main_id, 'associated_data': associated_data, 'filter_string': filter_string}

        return render(request, 'draw_sequence.html', context)
    else:
        return render(request, 'draw_sequence.html')


def get_updated_table_data(request):
    # Query the UploadedFile model and prepare data to send as JSON
    data = UploadedFile.objects.values('id', 'filename', 'uploadDate', 'processDate', 'processed', 'completed',
                                       'completeAt', 'isAnalysisComplete').order_by('id')
    return JsonResponse(list(data), safe=False)


# def showCucpWiseStats(request,id):
#     unique_cucp_ips = sh.get_cucp_ips(id)
#     context = {'cucp_ips': unique_cucp_ips}
#     return  render(request,'show_stats.html',context)


def show_stats(request, id):
    try:
        upload_file_id = id
        cumulative_stat_list = []
        identifier_stat_list = []
        sh.update_stats_by_id(upload_file_id)
        cumulative_stats = Stats.objects.filter(uploadedFiles_id=upload_file_id)
        for cumulative_stat in cumulative_stats:
            cumulative_stat_list.append({
                'category': cumulative_stat.category,
                'attempts': cumulative_stat.attempts,
                'success': cumulative_stat.success,
                'fails': cumulative_stat.fails,
                'timeouts': cumulative_stat.timeouts,
                'cucp_ip': f"{cumulative_stat.gnb_id}({cumulative_stat.cucp_f1c_ip})",

            })
        identifiers = IdentifiersStats.objects.filter(uploadedFiles_id=upload_file_id).order_by('identifier_id')
        unique_cucp_ips = sh.get_gnb_ids(id)

        identifier_stat_list = []
        for identifier in identifiers:
            identifier_obj = Identifiers.objects.get(id=identifier.identifier_id)

            identifier_stat_list.append({
                'identifier_id': identifier.identifier_id,
                'identifier_attempt': identifier.attempts,
                'identifier_success': identifier.success,
                'identifier_timeout': identifier.timeouts,
                "identifier_category": identifier.category,
                'identifier_fails': identifier.fails,
                'cucp_ip': f"{identifier.gnb_id}({identifier_obj.cucp_f1c_ip})",
                'c_rnti': f"{identifier_obj.c_rnti}_{identifier_obj.gnb_du_ue_f1ap_id}"

            })
        context = {
            'cumulative_stat_list': cumulative_stat_list,
            'identifier_stats_list': identifier_stat_list,
            'cucp_ips': unique_cucp_ips,
            "id": id,
        }
        print(unique_cucp_ips, cumulative_stat_list, unique_cucp_ips)
        return render(request, 'show_stats.html', context)
    except Exception as e:
        # Log the exception for debugging purposes
        logging.error(f"Error in show_stats view: {e}")
        return HttpResponseServerError("An error occurred while processing your request.")

# def chat_with_gptq(request):
#     if request.method == 'POST':
#         user_input = request.POST.get('user_input', '')
#         gptq_response = process_user_input(user_input)
#         return render(request, 'stats.html', {'user_input': user_input, 'gptq_response': gptq_response})
#         return render(request, 'stats.html')
